@@ -19,12 +19,18 @@ def main():
 		client = Client()
 		asyncio.run(client.connect(args))
 
+		client.close()
+
 	def server(args):
 		from .server import Server
+		from .server import cache
 
 		server = Server()
 		asyncio.run(server.start())
 
+		server.stop()
+		cache.save()
+
 	import argparse
 
 	parser = argparse.ArgumentParser(
