@@ -28,6 +28,3 @@ class Cache(Resource):
 			+ APP_NAME
 			+ '/cache.yaml'
 		)
-
-	def __del__(self):
-		self.save()
